Modules
- image
imageelement let’s you show an image.- label
labelsimply let’s you display some text.- paragraph
paragraphelement let’s you build texts with different styles.- rect
rectis a generic element that acts as a container for other elements.- svg
svgelement let’s you display SVG code.- text
textelement is simply a text span used for theparagraphelement.