freya_elements::elements

Struct paragraph

pub struct paragraph;
paragraph element let’s you build texts with different styles.

This used used with the text element.

fn app() -> Element {
    rsx!(
        paragraph {
            text {
                font_size: "15",
                "Hello, "
            }
            text {
                font_size: "30",
                "World!"
            }
        }
    )
}

Implementations

Source

impl paragraph

pub const height: AttributeDescription

Specify the width and height for the given element.

See syntax in Size Units.

Example
fn app() -> Element {
    rsx!(
        rect {
            background: "red",
            width: "15",
            height: "50",
        }
    )
}
pub const width: AttributeDescription

pub const min_height: AttributeDescription

min_width & min_height

rect supports specifying a minimum width and height, this can be useful if you use it alongside a percentage for the target size.

See syntax for Size Units.

Usage
fn app() -> Element {
    rsx!(
        rect {
            background: "red",
            min_width: "100",
            min_height: "100",
            width: "50%",
            height: "50%",
        }
    )
}
pub const min_width: AttributeDescription

pub const max_height: AttributeDescription

max_width & max_height

rect supports specifying a maximum width and height.

See syntax for Size Units.

Usage
fn app() -> Element {
    rsx!(
        rect {
            background: "red",
            max_width: "50%",
            max_height: "50%",
            width: "500",
            height: "500",
        }
    )
}
pub const max_width: AttributeDescription

pub const margin: AttributeDescription

Specify the margin of an element. You can do so by four different ways, just like in CSS.

Example
fn app() -> Element {
    rsx!(
        rect {
            margin: "25", // 25 in all sides
            margin: "100 50", // 100 in top and bottom, and 50 in left and right
            margin: "2 15 25", // 2 in top, 15 in left and right, and 25 in bottom
            margin: "5 7 3 9" // 5 in top, 7 in right, 3 in bottom and 9 in left
        }
    )
}
pub const position: AttributeDescription

Specify how you want the element to be positioned inside it’s parent area.

Accepted values:

  • stacked (default)
  • absolute (Floating element relative to the parent element)
  • global (Floating element relative to the window)

When using the absolute or global modes, you can also combine them with the following attributes:

  • position_top
  • position_right
  • position_bottom
  • position_left

These only support pixels.

Example
fn app() -> Element {
    rsx!(
        rect {
            width: "100%",
            height: "100%",
            rect {
                position: "absolute",
                position_bottom: "15",
                position_right: "15",
                background: "black",
                width: "100",
                height: "100",
            }
        }
    )
}
pub const position_top: AttributeDescription

pub const position_right: AttributeDescription

pub const position_bottom: AttributeDescription

pub const position_left: AttributeDescription

pub const layer: AttributeDescription

pub const main_align: AttributeDescription

main_align & cross_align

Control how the inner elements are positioned inside the element. You can combine it with the direction attribute to create complex flows.

Accepted values for main_align:

  • start (default): At the begining of the axis
  • center: At the center of the axis
  • end: At the end of the axis
  • space-between(only for main_align): Distributed among the available space
  • space-around (only for main_align): Distributed among the available space with small margins in the sides
  • space-evenly (only for main_align): Distributed among the available space with the same size of margins in the sides and in between the elements.

Accepted values for cross_align:

  • start (default): At the begining of the axis (same as in main_align)
  • center: At the center of the axis (same as in main_align)
  • end: At the end of the axis (same as in main_align)

When using the vertical direction, main_align will be the Y axis and cross_align will be the X axis. But when using the horizontal direction, the main_align will be the X axis and the cross_align will be the Y axis.

Example on how to center the inner elements in both axis:

fn app() -> Element {
    rsx!(
        rect {
            width: "100%",
            height: "100%",
            main_align: "center",
            cross_align: "center",
            rect {
                width: "50%",
                height: "50%",
                background: "red"
            },
        }
    )
}
pub const color: AttributeDescription

The color attribute lets you specify the color of the text.

You can learn about the syntax of this attribute in Color Syntax.

Example
fn app() -> Element {
    rsx!(
        label {
            color: "green",
            "Hello, World!"
        }
    )
}

Another example showing inheritance:

fn app() -> Element {
    rsx!(
        rect {
            color: "blue",
            label {
                "Hello, World!"
            }
        }
    )
}
pub const font_size: AttributeDescription

You can specify the size of the text using font_size.

Example
fn app() -> Element {
    rsx!(
        label {
            font_size: "50",
            "Hellooooo!"
        }
    )
}
pub const font_family: AttributeDescription

With the font_family you can specify what font you want to use for the inner text.

Check out the custom font example to see how you can load your own fonts.

Example
fn app() -> Element {
    rsx!(
        label {
            font_family: "Inter",
            "Hello, World!"
        }
    )
}
pub const font_style: AttributeDescription

You can choose a style for a text using the font_style attribute.

Accepted values:

  • upright (default)
  • italic
  • oblique
Example
fn app() -> Element {
    rsx!(
        label {
            font_style: "italic",
            "Hello, italic World!"
        }
    )
}

You can also specify multiple fonts in order of priority, if one is not found it will fallback to the next one.

Example:

fn app() -> Element {
    rsx!(
        label {
            font_family: "DoesntExist Font, Impact",
            "Hello, World!"
        }
    )
}
pub const font_weight: AttributeDescription

You can choose a weight for text using the font_weight attribute.

Accepted values:

  • invisible
  • thin
  • extra-light
  • light
  • normal (default)
  • medium
  • semi-bold
  • bold
  • extra-bold
  • black
  • extra-black
  • 50
  • 100
  • 200
  • 300
  • 400
  • 500
  • 600
  • 700
  • 800
  • 900
  • 950
Example
fn app() -> Element {
    rsx!(
        label {
            font_weight: "bold",
            "Hello, bold World!"
        }
    )
}
pub const font_width: AttributeDescription

You can choose a width for a text using the font_width attribute.

⚠️ Only fonts with variable widths will be affected.

Accepted values:

  • ultra-condensed
  • extra-condensed
  • condensed
  • normal (default)
  • semi-expanded
  • expanded
  • extra-expanded
  • ultra-expanded
Example
fn app() -> Element {
    rsx!(
        label {
            font_width: "ultra-expanded",
            "Hello, wide World!"
        }
    )
}
pub const text_align: AttributeDescription

You can change the alignment of the text using the text_align attribute.

Accepted values:

  • center
  • end
  • justify
  • left (default)
  • right
  • start
Example
fn app() -> Element {
    rsx!(
        label {
            text_align: "right",
            "Hello, World!"
        }
    )
}
pub const line_height: AttributeDescription

line_height

Specify the height of the lines of the text.

Example
fn app() -> Element {
    rsx!(
        label {
            line_height: "3",
            "Hello, World! \n Hello, again!"
        }
    )
}
pub const text_shadow: AttributeDescription

Specify the shadow of a text.

Syntax: <x> <y> <size> <color>

Example
fn app() -> Element {
    rsx!(
        label {
            text_shadow: "0 18 12 rgb(0, 0, 0)",
            "Hello, World!"
        }
    )
}
pub const max_lines: AttributeDescription

Determines the amount of lines that the text can have. It has unlimited lines by default.

Example
fn app() -> Element {
    rsx!(
        label {
            "Hello, World! \n Hello, World! \n Hello, world!" // Will show all three lines
        }
        label {
            max_lines: "2",
            "Hello, World! \n Hello, World! \n Hello, world!" // Will only show two lines
        }
    )
}
pub const decoration: AttributeDescription

Specify the decoration in a text.

Accepted values:

  • underline
  • line-through
  • overline
Example
fn app() -> Element {
    rsx!(
        label {
            decoration: "line-through",
            "Hello, World!"
        }
    )
}
pub const decoration_style: AttributeDescription

Specify the decoration’s style in a text.

Accepted values:

  • solid (default)
  • double
  • dotted
  • dashed
  • wavy
Example
fn app() -> Element {
    rsx!(
        label {
            decoration: "line-through",
            decoration_style: "dotted",
            "Hello, World!"
        }
    )
}
pub const decoration_color: AttributeDescription

Specify the decoration’s color in a text.

You can learn about the syntax of this attribute in Color Syntax.

Example
fn app() -> Element {
    rsx!(
        label {
            decoration: "line-through",
            decoration_color: "orange",
            "Hello, World!"
        }
    )
}
pub const text_overflow: AttributeDescription

Determines how text is treated when it exceeds its max_lines count. By default uses the clip mode, which will cut off any overflowing text, with ellipsis mode it will show ... at the end.

Accepted values:

  • clip (default)
  • ellipsis
Example
fn app() -> Element {
    rsx!(
        label {
            max_lines: "3",
            text_overflow: "ellipsis",
            "Looooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooong text"
        }
    )
}
pub const letter_spacing: AttributeDescription

Specify the spacing between characters of the text.

Example
fn app() -> Element {
    rsx!(
        label {
            letter_spacing: "10",
            "Hello, World!"
        }
    )
}
pub const word_spacing: AttributeDescription

Specify the spacing between words of the text.

Example
fn app() -> Element {
    rsx!(
        label {
            word_spacing: "10",
            "Hello, World!"
        }
    )
}
pub const text_height: AttributeDescription

Specify the text height behavior.

Accepted values:

  • disable-all (default)
  • all
  • disable-first-ascent
  • disable-least-ascent
Example
fn app() -> Element {
    rsx!(
        label {
            text_height: "disable-all",
            "Hello, World!"
        }
    )
}
pub const rotate: AttributeDescription

The rotate attribute let’s you rotate an element.

Compatible elements: all except text.

Example
fn app() -> Element {
    rsx!(
        label {
            rotate: "180deg",
            "Hello, World!"
        }
    )
}
pub const opacity: AttributeDescription

Specify the opacity of an element and all its descendants.

Example
fn app() -> Element {
    rsx!(
        rect {
            opacity: "0.5", // 50% visible
            label {
                "I am fading!"
            }
        }
    )
}
pub const cursor_index: AttributeDescription

pub const cursor_color: AttributeDescription

pub const cursor_mode: AttributeDescription

pub const cursor_id: AttributeDescription

pub const highlights: AttributeDescription

pub const highlight_color: AttributeDescription

pub const highlight_mode: AttributeDescription

pub const a11y_id: AttributeDescription

pub const a11y_focusable: AttributeDescription

pub const a11y_auto_focus: AttributeDescription

pub const a11y_name: AttributeDescription

pub const a11y_description: AttributeDescription

pub const a11y_value: AttributeDescription

pub const a11y_access_key: AttributeDescription

pub const a11y_author_id: AttributeDescription

pub const a11y_keyboard_shortcut: AttributeDescription

pub const a11y_language: AttributeDescription

pub const a11y_placeholder: AttributeDescription

pub const a11y_role_description: AttributeDescription

pub const a11y_state_description: AttributeDescription

pub const a11y_tooltip: AttributeDescription

pub const a11y_url: AttributeDescription

pub const a11y_row_index_text: AttributeDescription

pub const a11y_column_index_text: AttributeDescription

pub const a11y_scroll_x: AttributeDescription

pub const a11y_scroll_x_min: AttributeDescription

pub const a11y_scroll_x_max: AttributeDescription

pub const a11y_scroll_y: AttributeDescription

pub const a11y_scroll_y_min: AttributeDescription

pub const a11y_scroll_y_max: AttributeDescription

pub const a11y_numeric_value: AttributeDescription

pub const a11y_min_numeric_value: AttributeDescription

pub const a11y_max_numeric_value: AttributeDescription

pub const a11y_numeric_value_step: AttributeDescription

pub const a11y_numeric_value_jump: AttributeDescription

pub const a11y_row_count: AttributeDescription

pub const a11y_column_count: AttributeDescription

pub const a11y_row_index: AttributeDescription

pub const a11y_column_index: AttributeDescription

pub const a11y_row_span: AttributeDescription

pub const a11y_column_span: AttributeDescription

pub const a11y_level: AttributeDescription

pub const a11y_size_of_set: AttributeDescription

pub const a11y_position_in_set: AttributeDescription

pub const a11y_color_value: AttributeDescription

pub const a11y_expanded: AttributeDescription

pub const a11y_selected: AttributeDescription

pub const a11y_hovered: AttributeDescription

pub const a11y_hidden: AttributeDescription

pub const a11y_linked: AttributeDescription

pub const a11y_multiselectable: AttributeDescription

pub const a11y_required: AttributeDescription

pub const a11y_visited: AttributeDescription

pub const a11y_busy: AttributeDescription

pub const a11y_live_atomic: AttributeDescription

pub const a11y_modal: AttributeDescription

pub const a11y_touch_transparent: AttributeDescription

pub const a11y_read_only: AttributeDescription

pub const a11y_disabled: AttributeDescription

pub const a11y_is_spelling_error: AttributeDescription

pub const a11y_is_grammar_error: AttributeDescription

pub const a11y_is_search_match: AttributeDescription

pub const a11y_is_suggestion: AttributeDescription

pub const a11y_role: AttributeDescription

pub const a11y_invalid: AttributeDescription

pub const a11y_toggled: AttributeDescription

pub const a11y_live: AttributeDescription

pub const a11y_default_action_verb: AttributeDescription

pub const a11y_orientation: AttributeDescription

pub const a11y_sort_direction: AttributeDescription

pub const a11y_current: AttributeDescription

pub const a11y_auto_complete: AttributeDescription

pub const a11y_has_popup: AttributeDescription

pub const a11y_list_style: AttributeDescription

pub const a11y_vertical_offset: AttributeDescription