pub struct text;Expand description
text element is simply a text span used for the paragraph element.
Implementations
Sourceimpl text
impl text
Sourcepub const color: AttributeDescription
pub const color: AttributeDescription
The color attribute lets you specify the color of the text.
You can learn about the syntax of this attribute in Color Syntax.
Example
fn app() -> Element {
rsx!(
label {
color: "green",
"Hello, World!"
}
)
}Another example showing inheritance:
fn app() -> Element {
rsx!(
rect {
color: "blue",
label {
"Hello, World!"
}
}
)
}Sourcepub const font_size: AttributeDescription
pub const font_size: AttributeDescription
You can specify the size of the text using font_size.
Example
fn app() -> Element {
rsx!(
label {
font_size: "50",
"Hellooooo!"
}
)
}Sourcepub const font_family: AttributeDescription
pub const font_family: AttributeDescription
With the font_family you can specify what font you want to use for the inner text.
Check out the custom font example to see how you can load your own fonts.
Example
fn app() -> Element {
rsx!(
label {
font_family: "Inter",
"Hello, World!"
}
)
}Sourcepub const font_style: AttributeDescription
pub const font_style: AttributeDescription
You can choose a style for a text using the font_style attribute.
Accepted values:
upright(default)italicoblique
Example
fn app() -> Element {
rsx!(
label {
font_style: "italic",
"Hello, italic World!"
}
)
}You can also specify multiple fonts in order of priority, if one is not found it will fallback to the next one.
Example:
fn app() -> Element {
rsx!(
label {
font_family: "DoesntExist Font, Impact",
"Hello, World!"
}
)
}Sourcepub const font_weight: AttributeDescription
pub const font_weight: AttributeDescription
You can choose a weight for text using the font_weight attribute.
Accepted values:
invisiblethinextra-lightlightnormal(default)mediumsemi-boldboldextra-boldblackextra-black50100200300400500600700800900950
Example
fn app() -> Element {
rsx!(
label {
font_weight: "bold",
"Hello, bold World!"
}
)
}Sourcepub const font_width: AttributeDescription
pub const font_width: AttributeDescription
You can choose a width for a text using the font_width attribute.
⚠️ Only fonts with variable widths will be affected.
Accepted values:
ultra-condensedextra-condensedcondensednormal(default)semi-expandedexpandedextra-expandedultra-expanded
Example
fn app() -> Element {
rsx!(
label {
font_width: "ultra-expanded",
"Hello, wide World!"
}
)
}Sourcepub const text_align: AttributeDescription
pub const text_align: AttributeDescription
You can change the alignment of the text using the text_align attribute.
Accepted values:
centerendjustifyleft(default)rightstart
Example
fn app() -> Element {
rsx!(
label {
text_align: "right",
"Hello, World!"
}
)
}Sourcepub const line_height: AttributeDescription
pub const line_height: AttributeDescription
Sourcepub const text_shadow: AttributeDescription
pub const text_shadow: AttributeDescription
Specify the shadow of a text.
Syntax: <x> <y> <size> <color>
Example
fn app() -> Element {
rsx!(
label {
text_shadow: "0 18 12 rgb(0, 0, 0)",
"Hello, World!"
}
)
}Sourcepub const decoration: AttributeDescription
pub const decoration: AttributeDescription
Specify the decoration in a text.
Accepted values:
underlineline-throughoverline
Example
fn app() -> Element {
rsx!(
label {
decoration: "line-through",
"Hello, World!"
}
)
}Sourcepub const decoration_style: AttributeDescription
pub const decoration_style: AttributeDescription
Specify the decoration’s style in a text.
Accepted values:
solid(default)doubledotteddashedwavy
Example
fn app() -> Element {
rsx!(
label {
decoration: "line-through",
decoration_style: "dotted",
"Hello, World!"
}
)
}Sourcepub const decoration_color: AttributeDescription
pub const decoration_color: AttributeDescription
Specify the decoration’s color in a text.
You can learn about the syntax of this attribute in Color Syntax.
Example
fn app() -> Element {
rsx!(
label {
decoration: "line-through",
decoration_color: "orange",
"Hello, World!"
}
)
}Sourcepub const letter_spacing: AttributeDescription
pub const letter_spacing: AttributeDescription
Specify the spacing between characters of the text.
Example
fn app() -> Element {
rsx!(
label {
letter_spacing: "10",
"Hello, World!"
}
)
}Sourcepub const word_spacing: AttributeDescription
pub const word_spacing: AttributeDescription
Specify the spacing between words of the text.
Example
fn app() -> Element {
rsx!(
label {
word_spacing: "10",
"Hello, World!"
}
)
}Auto Trait Implementations
impl Freeze for text
impl RefUnwindSafe for text
impl Send for text
impl Sync for text
impl Unpin for text
impl UnwindSafe for text