Module text

Module text 

text element is simply a text span used for the paragraph element.

Constants

color
The color attribute lets you specify the color of the text.
decoration
Specify the decoration in a text.
decoration_color
Specify the decoration’s color in a text.
decoration_style
Specify the decoration’s style in a text.
font_family
With the font_family you can specify what font you want to use for the inner text.
font_size
You can specify the size of the text using font_size.
font_style
You can choose a style for a text using the font_style attribute.
font_weight
You can choose a weight for text using the font_weight attribute.
font_width
You can choose a width for a text using the font_width attribute.
letter_spacing
Specify the spacing between characters of the text.
line_height
line_height
text_align
You can change the alignment of the text using the text_align attribute.
text_shadow
Specify the shadow of a text.
word_spacing
Specify the spacing between words of the text.