Structs
- File
Data - Data of a File event.
Functions
- onfiledrop
- The
filedropevent fires when the user drops a file over the element. - onglobalfilehover
- The
onglobalfilehoverevent fires when the user hovers a file over the window. - onglobalfilehovercancelled
- The
onglobalfilehovercancelledevent fires when the user cancels the hovering of a file over the window. It’s the opposite ofonglobalfilehover.