Module keyboard
Source - KeyboardData
- Data of a Keyboard event.
- Modifiers
- Pressed modifier keys.
- Code
- Code is the physical position of a key.
- Key
- Key represents the meaning of a keypress.
- onglobalkeydown
- The
globalkeydown event fires when the user starts pressing any key. - onglobalkeyup
- The
globalkeyup event fires when the user releases any key being pressed. - onkeydown
- The
keydown event fires when the user starts pressing any key in the currently focused element. - onkeyup
- The
keyup event fires when the user releases any key being pressed in the currently focused element.