Module mouse

Structs

MouseData
Data of a Mouse event.

Enums

MouseButton
Describes a button of a mouse controller.

Functions

onclick
The click event fires when the user starts and ends a click in an element with the left button of the mouse.
onglobalclick
The globalclick event fires when the user clicks anywhere. Note that this fires for all mouse buttons. You can check the specific variant with the MouseData’s trigger_button property.
onglobalmousedown
The globalmousedown event fires when the user starts clicking anywhere. Note that this fires for all mouse buttons. You can check the specific variant with the MouseData’s trigger_button property.
onglobalmousemove
The globalmousemove event fires when the user moves the mouse anywhere in the app.
onmiddleclick
The click event fires when the user clicks an element with the middle button of the mouse.
onmousedown
The mousedown event fires when the user starts clicking an element. Note that this fires for all mouse buttons. You can check the specific variant with the MouseData’s trigger_button property.
onmouseenter
The mouseenter event fires when the user starts hovering an element.
onmouseleave
The mouseleave event fires when the user stops hovering an element.
onmousemove
The mousemove event fires when the user moves the mouse over an element. Unlike onmouseenter, this fires even if the user was already hovering over the element. For that reason, it’s less efficient.
onmouseup
The mouseup event fires when the user ends the click in an element with the left button of the mouse.
onrightclick
The click event fires when the user clicks an element with the right button of the mouse.