Constants
- text_
overflow - Determines how text is treated when it exceeds its
max_linescount. By default uses theclipmode, which will cut off any overflowing text, withellipsismode it will show...at the end.
max_lines count. By default uses the clip mode, which will cut off any overflowing text, with ellipsis mode it will show ... at the end.