Module elements

Modules

image
image element let’s you show an image.
label
label simply let’s you display some text.
paragraph
paragraph element let’s you build texts with different styles.
rect
rect is a generic element that acts as a container for other elements.
svg
svg element let’s you display SVG code.
text
text element is simply a text span used for the paragraph element.