text element is simply a text span used for the paragraph element.
Constants
- color
- The
colorattribute lets you specify the color of the text. - decoration
- Specify the decoration in a text.
- decoration_
color - Specify the decoration’s color in a text.
- decoration_
style - Specify the decoration’s style in a text.
- font_
family - With the
font_familyyou can specify what font you want to use for the inner text. - font_
size - You can specify the size of the text using
font_size. - font_
style - You can choose a style for a text using the
font_styleattribute. - font_
weight - You can choose a weight for text using the
font_weightattribute. - font_
width - You can choose a width for a text using the
font_widthattribute. - letter_
spacing - Specify the spacing between characters of the text.
- line_
height - line_height
- text_
align - You can change the alignment of the text using the
text_alignattribute. - text_
shadow - Specify the shadow of a text.
- word_
spacing - Specify the spacing between words of the text.