Module file

Structs

FileData
Data of a File event.

Functions

onfiledrop
The filedrop event fires when the user drops a file over the element.
onglobalfilehover
The onglobalfilehover event fires when the user hovers a file over the window.
onglobalfilehovercancelled
The onglobalfilehovercancelled event fires when the user cancels the hovering of a file over the window. It’s the opposite of onglobalfilehover.