The globalclick event fires when the user clicks anywhere.
Note that this fires for all mouse buttons.
You can check the specific variant with the MouseData’s trigger_button property.
The globalmousedown event fires when the user starts clicking anywhere.
Note that this fires for all mouse buttons.
You can check the specific variant with the MouseData’s trigger_button property.
The mousedown event fires when the user starts clicking an element.
Note that this fires for all mouse buttons.
You can check the specific variant with the MouseData’s trigger_button property.
The mousemove event fires when the user moves the mouse over an element.
Unlike onmouseenter, this fires even if the user was already hovering over
the element. For that reason, it’s less efficient.